Description Usage Arguments Value Examples
Searches for an executable in a some places and use the highest version found (unless a specific version is requested).
1 |
exec |
executable identifier, a single character. Use one of these values:
|
cache |
if |
dir |
A character vector of directory paths under which the executable may be found. |
version |
The version of the executable to look for (e.g., |
A list containing the directory and version of the executable if found. If not found,
the version will be 0 and the dir will be NULL.
1 2 3 4 5 6 7 | locate_exec("chrome")
locate_exec("chrome", version = "88.0.4324.150")
locate_exec("libreoffice")
locate_exec("node")
locate_exec("npm")
locate_exec("python")
locate_exec("pip")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.